# processamento_imagens_pythonico_DIO

Description. 
The package processamento_imagens_pythonico_DIO is used to:
	Processing
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histograms

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install processamento_imagens_pythonico_DIO

```bash
pip install processamento_imagens_pythonico_DIO
```

## Author
Guilherme

## License
[MIT](https://choosealicense.com/licenses/mit/)